.. _contact:

************************
Author, license, contact
************************
gipc is written and maintained by `Jan-Philip Gehrcke <https://gehrcke.de>`_ and
licensed under the MIT license (see `LICENSE
<https://github.com/jgehrcke/gipc/blob/master/LICENSE>`_ file for details). Your
feedback is highly appreciated. You can contact me at jgehrcke@googlemail.com or
use the `GitHub issue tracker <https://github.com/jgehrcke/gipc/issues>`_.

I am thankful for all contributions (bug reports, code, great questions) from:

- Guy Rozendorn
- John Ricklefs
- Heungsub Lee
- Alex Besogonov
- Jonathan Kamens
- Akhil Acharya
- John Porter
- James Addison
- Oliver Margetts
- ... and others
